@@ -5,7 +5,7 @@
 *
 * @package language
 * @version Id: board.php 11245 2011-06-16 14:15:09Z git-gate $
-* @version $Id: board.php 147 2011-06-19 10:57:31Z jan skovsgaard $
+* @version $Id: board.php 221 2012-05-31 18:54:59Z Jan Skovsgaard $
 * @source file is copyright (c) 2005 phpBB Group
 * @modified and translated by Olympus DK Team
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
@@ -69,7 +69,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'Tidszone for gæster',
 	'SYSTEM_TIMEZONE_EXPLAIN'      => 'Den tidszone der vises for brugere der ikke er logget ind (gæster, botter). Tilmeldte brugere vælger selv foretrukken tidszone under tilmeldingen og kan ændre denne i brugerkontrolpanelet.',
 	'WARNINGS_EXPIRE'				=> 'Varighed for advarsler',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Antal dage fra en advarsel udstedes, til den fjernes fra brugeres profildata.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Antal dage fra en advarsel udstedes, til den fjernes fra brugeres profildata. Angives 0, vil advarslen være permanent.',
 ));
 
 // Board Features
@@ -124,7 +124,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'Største dimensioner for avatar',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Bredde x højde i pixels.',
 	'MAX_FILESIZE'					=> 'Maksimal filstørrelse for avatar',
-	'MAX_FILESIZE_EXPLAIN'			=> 'For uploadede avatarfiler.',
+	'MAX_FILESIZE_EXPLAIN'			=> 'For uploadede avatarfiler. Er størrelsen sat til 0, er det alene din interne PHP-konfiguration, der begrænser filstørrelsen.',
 	'MIN_AVATAR_SIZE'				=> 'Mindste dimensioner for avatar',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'Bredde x højde i pixels.',
 ));
@@ -190,7 +190,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Maksimalt antal links i indlæg',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Højeste antal URL\'er pr. indlæg. Sæt til 0 for ubegrænset antal links.',
 	'MIN_CHAR_LIMIT'					=> 'Mindste antal tegn pr. meddelelse',
-	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Indlæg og private beskeder skal indeholde minimum dette antal tegn.',
+	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Indlæg og private beskeder skal indeholde minimum dette antal tegn. 1 er den mindste værdi i denne indstilling.',
 	'POSTING'						=> 'Indlæg',
 	'POSTS_PER_PAGE'				=> 'Indlæg pr. side',
 	'QUOTE_DEPTH_LIMIT'				=> 'Maksimal dybde for citeringer',
