@@ -5,7 +5,7 @@
 *
 * @package language
 * @version Id: common.php 10848 2010-11-07 14:00:05Z git-gate $
-* @version $Id: common.php 146 2011-06-16 14:20:44Z jan skovsgaard $
+* @version $Id: common.php 225 2012-06-04 19:34:45Z Jan Skovsgaard $
 * @source file is copyright (c) 2005 phpBB Group
 * @modified and translated by Olympus DK Team
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
@@ -342,6 +342,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'Databaseserver',
 	'DATABASE_SIZE'			=> 'Databasestørrelse',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Funktionen overloading er fejlkonfigureret',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> skal konfigureres til enten 0 eller 4. Den nuværende konfiguration kan kontrolleres under <samp>PHP-indstillinger</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Transparent character encoding er fejlkonfigureret',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> skal konfigureres til 0. Den nuværende konfiguration kan kontrolleres under <samp>PHP-indstillinger</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input character conversion er fejlkonfigureret',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> skal konfigureres til <samp>pass</samp>. Den nuværende konfiguration kan kontrolleres under <samp>PHP-indstillinger</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output character conversion er fejlkonfigureret',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> skal konfigureres til <samp>pass</samp>. Den nuværende konfiguration kan kontrolleres under <samp>PHP-indstillinger</samp>.',
+
 	'FILES_PER_DAY'		=> 'Antal vedhæftede filer pr. dag',
 	'FORUM_STATS'		=> 'Boardstatistikker',
 
@@ -357,6 +367,7 @@ $lang = array_merge($lang, array(
 	'PHP_VERSION_OLD'	=> 'Den PHP-version der er installeret på denne server understøttes ikke i fremtidige versioner af phpBB. %sDetails%s',
 
 	'POSTS_PER_DAY'		=> 'Indlæg pr. dag',
+
 	'PURGE_CACHE'		=> 'Tøm cachen',
 	'PURGE_CACHE_CONFIRM'	=> 'Er du sikker på du vil tømme cachen?', 
 	'PURGE_CACHE_EXPLAIN'	=> 'Sletter alt i cachen, dette inkluderer mellemlagrede skabelonfiler og søgninger.',
@@ -408,8 +419,8 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_REMIND'		=> 'Tvungen genaktivering af brugerkonto',
 	'INACTIVE_REASON_UNKNOWN'		=> 'Ukendt',
 	'INACTIVE_USERS'				=> 'Inaktive brugere',
-	'INACTIVE_USERS_EXPLAIN'		=> 'Dette er en liste over brugere som er tilmeldt men hvis konti er inaktive. Du kan aktivere, slette eller erindre disse brugere pr. email hvis du ønsker det.',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'De seneste 10 tilmeldte brugere med inaktive konti. En fuldstændig liste er tilgængelig ved at følge linket nedenfor, hvorfra du har mulighed for at aktivere, slette eller sende påmindelser til disse brugere. Samme liste kan også ses via fanebladet "Brugere & Grupper".',
+	'INACTIVE_USERS_EXPLAIN'		=> 'Dette er en liste over brugere som er tilmeldt, men hvis konti er inaktive. Du kan aktivere, slette eller påminde disse brugere pr. email.',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'De seneste 10 tilmeldte brugere med inaktive konti. Konti kan være inaktive fordi aktivering ikke er gennemført af brugere, eller fordi konti er blevet deaktiveret. En fuldstændig liste er tilgængelig ved at følge linket nedenfor. Herfra får du også mulighed for at aktivere, slette eller sende påmindelser til disse brugere. Samme liste kan også ses via fanebladet "Brugere & Grupper".',
 
 	'NO_INACTIVE_USERS'	=> 'Ingen inaktive brugere',
 
