@@ -5,7 +5,7 @@
 *
 * @package language
 * @version Id: posting.php 11098 2011-04-11 00:00:08Z git-gate $
-* @version $Id: posting.php 130 2011-04-11 05:39:24Z jan skovsgaard $
+* @version $Id: posting.php 159 2011-07-17 09:40:13Z Jan Skovsgaard $
 * @source file is copyright (c) 2005 phpBB Group
 * @modified and translated by Olympus DK Team
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
@@ -107,9 +107,9 @@ $lang = array_merge($lang, array(
 $lang = array_merge($lang, array(
 	'ACP_ICONS_EXPLAIN'		=> 'Her kan du tilføje, fjerne og rette ikonerne som brugerne kan tilføje til deres emner eller indlæg. Disse ikoner vises generelt ved siden af emnetitler på forumoversigten, eller ved emnetitlerne i emnevisningerne. Du kan også installere og oprette nye ikonpakker.',
 	'ACP_SMILIES_EXPLAIN'	=> 'Smilies er typisk små, nogle gange animerede billeder der bruges til at give udtryk for en følelse eller mening. Fra denne side kan du tilføje, fjerne og rette de smilies som brugerne kan bruge i deres indlæg og private beskeder. Du kan også installere og oprette nye pakker med smilies.',
-	'ADD_SMILIES'			=> 'Tilføj mange smilies',
+	'ADD_SMILIES'			=> 'Tilføj smilies',
 	'ADD_SMILEY_CODE'		=> 'Tilføj yderligere smileykode',
-	'ADD_ICONS'				=> 'Tilføj mange ikoner',
+	'ADD_ICONS'				=> 'Tilføj ikoner',
 	'AFTER_ICONS'			=> 'Efter %s',
 	'AFTER_SMILIES'			=> 'Efter %s',
 
