@@ -5,7 +5,7 @@
 *
 * @package language
 * @version Id: common.php 11057 2011-03-13 04:45:12Z git-gate $
-* @version $Id: common.php 139 2011-05-26 19:11:21Z jan skovsgaard $
+* @version $Id: common.php 218 2012-04-20 19:22:19Z Jan Skovsgaard $
 * @source file is copyright (c) 2005 phpBB Group
 * @modified and translated by Olympus DK Team
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
@@ -55,7 +55,7 @@ if (empty($lang) || !is_array($lang))
 //
 
 $lang = array_merge($lang, array(
-	'TRANSLATION_INFO'	=> 'Danish translation by <a href="http://www.olympusdkteam.dk">Olympus DK Team</a>',
+	'TRANSLATION_INFO'	=> 'Danish translation &amp; support by <a href="http://www.olympusdkteam.dk">Olympus DK Team</a>',
 	'DIRECTION'	=> 'ltr',
 	'DATE_FORMAT'	=> '|j. M Y|',// 1. jan 2007 (med relative dage aktiveret)
 	'USER_LANG'			=> 'da',
@@ -180,6 +180,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'	=> 'Du skal angive en titel når du skriver en ny besked.',
 	'ENABLED'	=> 'Aktiv',
 	'ENCLOSURE'	=> 'Bilag',
+	'ENTER_USERNAME'          => 'Angiv brugernavn',
 	'ERR_CHANGING_DIRECTORY'	=> 'Kunne ikke skifte mappe.',
 	'ERR_CONNECTING_SERVER'	=> 'Kunne ikke forbinde til server.',
 	'ERR_JAB_AUTH'			=> 'Kunne ikke autoriseres på Jabberserver.',
@@ -205,7 +206,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'			=> 'Den indsendte formular var ugyldig. Prøv at indsende igen.',
 	'FORUM'	=> 'Forum',
 	'FORUMS'	=> 'Fora',
-	'FORUMS_MARKED'	=> 'Valgte fora er markeret læste.',
+	'FORUMS_MARKED'	=> 'Fora blev markeret læste.',
 	'FORUM_CAT'	=> 'Forumkategori',
 	'FORUM_INDEX'	=> 'Boardindeks',
 	'FORUM_LINK'	=> 'Forumlink',
@@ -215,6 +216,8 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'Klik venligst her for at læse forumreglerne',
 	'FROM'	=> 'fra',
 	'FSOCK_DISABLED'	=> 'Handlingen kunne ikke gennemføres fordi funktionen <var>fsockopen</var> er deaktiveret, eller fordi den forespurgte server ikke kunne findes.',
+	'FSOCK_TIMEOUT'      => 'Der opstod en timeout under læsning af network stream.',
+
 	'FTP_FSOCK_HOST'	=> 'FTP-vært',
 	'FTP_FSOCK_HOST_EXPLAIN'	=> 'FTP-server brugt til at forbinde dit site.',
 	'FTP_FSOCK_PASSWORD'	=> 'FTP-kodeord',
@@ -397,7 +400,7 @@ $lang = array_merge($lang, array(
 	'NO_NEW_MESSAGES'	=> 'Ingen nye beskeder',
 	'NO_NEW_PM'	=> '<strong>0</strong> nye beskeder',
 	'NO_NEW_POSTS'	=> 'Ingen nye indlæg', // Not used anymore
-	'NO_ONLINE_USERS'			=> 'Ingen tilmeldte',
+	'NO_ONLINE_USERS'			=> 'Ingen',
 	'NO_POSTS'	=> 'Ingen indlæg',
 	'NO_POSTS_TIME_FRAME'		=> 'Ingen indlæg eksisterer i dette emne inden for det valgte tidsinterval.',
 	'NO_FEED_ENABLED'	=> 'Feeds er ikke tilgængelige på dette board.',
@@ -462,6 +465,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'	=> 'Skrevet',
 	'POST_TOPIC'	=> 'Skriv et nyt emne',
 	'POST_UNAPPROVED'	=> 'Dette indlæg afventer godkendelse.',
+	'POWERED_BY'      => 'Powered by %s',
 	'PREVIEW'	=> 'Vis prøve',
 	'PREVIOUS'	=> 'Foregående',// Used in pagination
 	'PREVIOUS_STEP'	=> 'Foregående',
@@ -471,6 +475,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGING'	=> 'Private beskeder',
 	'PROFILE'	=> 'Brugerkontrolpanel',
 
+	'RANK'					=> 'Rang',
 	'READING_FORUM'	=> 'Læser emner i %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Læser global bekendtgørelse',
 	'READING_LINK'	=> 'Følger forumlink %s',
@@ -481,7 +486,7 @@ $lang = array_merge($lang, array(
 	'REDIRECT'	=> 'Viderestil',
 	'REDIRECTS'	=> 'Viderestillinger',
 	'REGISTER'	=> 'Tilmeld',
-	'REGISTERED_USERS'	=> 'Tilmeldte brugere:',
+	'REGISTERED_USERS'	=> 'Tilmeldte online:',
 	'REG_USERS_ONLINE'	=> 'Der er %d tilmeldte brugere og ',
 	'REG_USERS_TOTAL'	=> '%d tilmeldte, ',
 	'REG_USERS_TOTAL_AND'		=> '%d tilmeldte og ',
@@ -666,6 +671,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'	=> '<strong>%d</strong> ulæste beskeder',
 	'UNREAD_POST'      => 'Ulæst indlæg',
 	'UNREAD_POSTS'      => 'Ulæste indlæg',
+	'UNWATCH_FORUM_CONFIRM'    => 'Er du sikker på at du vil stoppe overvågning af dette forum?',
+	'UNWATCH_FORUM_DETAILED'  => 'Er du sikker på at du vil stoppe overvågning af forummet "%s"?',
+	'UNWATCH_TOPIC_CONFIRM'    => 'Er du sikker på at du vil stoppe overvågning af dette emne?',
+	'UNWATCH_TOPIC_DETAILED'  => 'Er du sikker på at du vil stoppe overvågning af emnet "%s"?',
 	'UNWATCHED_FORUMS'	=> 'Du overvåger ikke længere de valgte fora.',
 	'UNWATCHED_TOPICS'	=> 'Du overvåger ikke længere de valgte emner.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Du overvåger ikke længere de valgte fora og emner.',
@@ -714,6 +723,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'	=> 'Advarsler',
 	'WARN_USER'	=> 'Advar bruger',
+	'WATCH_FORUM_CONFIRM'  => 'Er du sikker på at du ønsker at overvåge dette forum?',
+	'WATCH_FORUM_DETAILED'  => 'Er dy sikker på at du ønsker at overvåge forummet "%s"?',
+	'WATCH_TOPIC_CONFIRM'  => 'Er du sikker på at du ønsker at overvåge dette emne?',
+	'WATCH_TOPIC_DETAILED'  => 'Er du sikker på at du ønsker at overvåge emnet "%s"?',
 	'WELCOME_SUBJECT'	=> 'Velkommen til %s',
 	'WEBSITE'	=> 'Hjemmeside',
 	'WHOIS'	=> 'Whois',
